@@ -14,7 +14,7 @@ app = FastAPI()
 
 
 @app.get("/api/{item_id}")
-async def root(request: Request, item_id: str):
+def root(request: Request, item_id: str):
     """
     接收接口名称及其参数并返回 JSON 数据
     :param request: 请求信息
@@ -27,17 +27,23 @@ async def root(request: Request, item_id: str):
     interface_list = dir(ak)
     decode_params = urllib.parse.unquote(str(request.query_params))
     if item_id not in interface_list:
-        return {'error': '没有该接口'}
+        return {'error': '未找到该接口，请升级 AKShare 到最新版本并在文档中确认该接口的使用方式：https://www.akshare.xyz'}
     eval_str = decode_params.replace("&", '", ').replace("=", '="') + '"'
     if not bool(request.query_params):
         try:
-            temp_df = eval("ak." + item_id + f"()").to_json(orient='records', date_format='iso')
+            received_df = eval("ak." + item_id + f"()")
+            if received_df is None:
+                return {'error': '该接口返回数据为空，请确认参数是否正确：https://www.akshare.xyz'}
+            temp_df = received_df.to_json(orient='records', date_format='iso')
         except KeyError as e:
-            return {'error': '参数错误'}
+            return {'error': f'请输入正确的参数错误 {e}，请升级 AKShare 到最新版本并在文档中确认该接口的使用方式：https://www.akshare.xyz'}
         return json.loads(temp_df)
     else:
         try:
-            temp_df = eval("ak." + item_id + f"({eval_str})").to_json(orient='records', date_format='iso')
+            received_df = eval("ak." + item_id + f"({eval_str})")
+            if received_df is None:
+                return {'error': '该接口返回数据为空，请确认参数是否正确：https://www.akshare.xyz'}
+            temp_df = received_df.to_json(orient='records', date_format='iso')
         except KeyError as e:
-            return {'error': f'请输入正确的参数错误 {e} '}
+            return {'error': f'请输入正确的参数错误 {e}，请升级 AKShare 到最新版本并在文档中确认该接口的使用方式：https://www.akshare.xyz'}
         return json.loads(temp_df)
